
function meshSetup()
    
    --make mesh
    meshyMesh = mesh()
    
    --set shader and initial variables
    meshyMesh.shader = shader(Undulate.vertexShader, Undulate.fragmentShader)
    local overallSideLength = math.min(WIDTH, HEIGHT)
    
    --function for resetting mesh based on new square count
    function makeMeshSquares()    
        meshyMesh.vertices, meshyMesh.colors = vertsAndColorsBasedOn(squaresPerSide, overallSideLength)
        setMeshDistanceBufferFor(meshyMesh, squaresPerSide, verticalDistanceIncrement)       
    end    
end

--define, for shader, which square each vertex is a part of
function setMeshDistanceBufferFor(meshUsed, squaresPerSide, verticalDistanceIncrement)
    local distancesOfSubSquares = distancesBySquareBelongedTo(squaresPerSide, verticalDistanceIncrement)
    local distanceBuffer = meshUsed:buffer("distanceFromCenter")
    distanceBuffer:resize(#distancesOfSubSquares)
    for i, distance in ipairs(distancesOfSubSquares) do
        distanceBuffer[i] = distance
    end
end

--# Mesh Undulate Shader
Undulate = {
    
    vertexShader = [[
    //
    // Vertex shader: Undulate
    //
    
    uniform mat4 modelViewProjection;
    uniform float time;
    
    attribute vec4 position;
    attribute vec4 color;
    attribute float distanceFromCenter; 
    
    varying lowp vec4 vColor;
    
    void main() {
        float z = 50.0 * sin(distanceFromCenter + time);
        vec4 p = vec4(position.x, position.y, z, position.w);
        vColor = color;
        gl_Position = modelViewProjection * p;
    }
]],

fragmentShader = [[
//
// Fragment shader: Undulate
//

varying lowp vec4 vColor;

void main() {
gl_FragColor = vColor;
}
]]
}

--[[
--the original function that created the mesh and defined how to remake it
function meshSetupOriginal()
    meshyMesh = mesh()
    meshyMesh.shader = shader(Undulate.vertexShader, Undulate.fragmentShader)
    function meshReset()
        local midSide = squaresPerSide/2 - 0.5       
        local distanceBuffer = meshyMesh:buffer("distanceFromCenter")
        distanceBuffer:resize(squaresPerSide * squaresPerSide * 6)
        local verticesOfSubSquares = {}
        local colorsForEachSubSquare = {}
        local squareSideLength = math.min(WIDTH, HEIGHT) / squaresPerSide
        cameraFocuser = squaresPerSide / 2 * squareSideLength
        for row = 0, squaresPerSide - 1 do
            local rowY = row - midSide
            local ySqr = rowY * rowY
            for column = 0, squaresPerSide - 1 do
                local columnX = column - midSide
                local localDistanceFromCenter = math.sqrt(columnX * columnX + ySqr) * verticalDistanceIncrement / squaresPerSide
                local x = column * squareSideLength
                local y = row * squareSideLength
                local squareColor = randomColor()
                quickTableInsert(verticesOfSubSquares, vec3(x, y, 0))
                quickTableInsert(verticesOfSubSquares, vec3(x + squareSideLength, y, 0))
                quickTableInsert(verticesOfSubSquares, vec3(x, y + squareSideLength, 0))
                quickTableInsert(verticesOfSubSquares, vec3(x, y + squareSideLength, 0))
                quickTableInsert(verticesOfSubSquares, vec3(x + squareSideLength, y, 0))
                quickTableInsert(verticesOfSubSquares, vec3(x + squareSideLength, y + squareSideLength, 0))
                for individualSubSquareVertex = 1, 6 do
                    quickTableInsert(colorsForEachSubSquare, squareColor)
                    -- Needs to be a vec2 to work in Codea beta 1.5(16)
                    distanceBuffer[(column + row * squaresPerSide) * 6 + individualSubSquareVertex] = localDistanceFromCenter
                end
            end
        end
        local vertices = verticesOfSubSquares
        print(vertices[1], vertices[2], vertices[3], vertices[4], vertices[5], vertices[6])
        meshyMesh.vertices = verticesOfSubSquares
        meshyMesh.colors = colorsForEachSubSquare
    end      
end
]]