
function vertsAndColorsBasedOn(squaresPerSide, overallSideLength, craftFlag)
    local verts = vertsBasedOn(squaresPerSide, overallSideLength, craftFlag)
    local colors = randomColorsBySquareBelongedTo(#verts)
    local numericalSequence = numericalSequenceTo(#verts)
    --last value only used by craft version
    return verts, colors, numericalSequence
end

function vertsBasedOn(squaresPerSide, overallSideLength, craftFlag)
    local midSide = squaresPerSide/2 - 0.5       
    local squareSideLength = overallSideLength / squaresPerSide
    local verticesForSquares = {}
    for row = 0, squaresPerSide - 1 do
        local rowY = row - midSide
        local ySqr = rowY * rowY
        for column = 0, squaresPerSide - 1 do
            local columnX = column - midSide
            local x = column * squareSideLength
            local towardsScreenTop = row * squareSideLength
            --craft and mesh put their vec3s in different orders
            if craftFlag then
                addVecsForSquare(verticesForSquares, x, 0, towardsScreenTop, squareSideLength)
            else
                addVecsForSquare(verticesForSquares, x, towardsScreenTop, 0, squareSideLength)
            end
        end
    end
    return verticesForSquares
end

function addVecsForSquare(destinationTable, x, y, z, squareSideLength)
    if y == 0 then
        --meshes are using z values to stack rows, leaving y as 0
        quickTableInsert(destinationTable, vec3(x, 0, z))
        quickTableInsert(destinationTable, vec3(x + squareSideLength, 0, z))
        quickTableInsert(destinationTable, vec3(x, 0, z + squareSideLength))
        quickTableInsert(destinationTable, vec3(x, 0, z + squareSideLength))
        quickTableInsert(destinationTable, vec3(x + squareSideLength, 0, z))
        quickTableInsert(destinationTable, vec3(x + squareSideLength, 0, z + squareSideLength))
    else
        -- craft is using y values to stack rows, leaving z as 0
        quickTableInsert(destinationTable, vec3(x, y, 0))
        quickTableInsert(destinationTable, vec3(x + squareSideLength, y, 0))
        quickTableInsert(destinationTable, vec3(x, y + squareSideLength, 0))
        quickTableInsert(destinationTable, vec3(x, y + squareSideLength, 0))
        quickTableInsert(destinationTable, vec3(x + squareSideLength, y, 0))
        quickTableInsert(destinationTable, vec3(x + squareSideLength, y + squareSideLength, 0))
    end
end

function randomColorsBySquareBelongedTo(sizeOfDesiredTable)
    local colorTable = {}
    for i = 1, sizeOfDesiredTable / 6 do
        local newColor = color(
        math.random(255),
        math.random(255),
        math.random(255))
        for chunk = 1, 6 do
            quickTableInsert(colorTable, newColor)
        end
    end
    return colorTable
end

function distancesBySquareBelongedTo(squaresPerSide, verticalIncrement)
    local midSide = squaresPerSide/2 - 0.5       
    local distanceTable = {}
    for row = 0, squaresPerSide - 1 do
        local ySqr = (row - midSide) ^ 2
        for column = 1, squaresPerSide do
            local columnX = column - midSide
            local thisDistance = math.sqrt(columnX * columnX + ySqr) * verticalIncrement / squaresPerSide
            for bunch = 1, 6 do
                quickTableInsert(distanceTable, thisDistance)
            end
        end
    end
    return distanceTable
end

function numericalSequenceTo(highestNumber)
    local sequenceTable = {}
    for i = 1, highestNumber do
        sequenceTable[i] = i
    end
    return sequenceTable
end
